@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, unicode_literals
-from datetime import date
+from datetime import date, timedelta
 from django.db import models
 from django.conf import settings
 from django.conf.urls import patterns, include, url
@@ -31,8 +31,10 @@ class TestModel(models.Model):
     attr_int = models.IntegerField(blank=True, null=True)
     attr_fk = models.ForeignKey(TestFkModel, blank=True, null=True)
     attr_fk_notnull = models.ForeignKey(TestFkModel, related_name='foreign_key_notnull')
-    attr_datetime = models.DateTimeField(blank=True, null=True)
-    attr_date = models.DateField(blank=True, null=True)
+    attr_datetime = models.DateTimeField(default=now)
+    attr_date = models.DateField(default=date.today)
+    attr_datetimenull = models.DateTimeField(blank=True, null=True)
+    attr_datenull = models.DateField(blank=True, null=True)
 
     class Meta:
         db_table = 'versioning_testmodel'
@@ -42,7 +44,8 @@ class TestModel(models.Model):
 
 versioning.register(
     TestModel,
-    ['attr_text', 'attr_int', 'attr_bool', 'attr_fk', 'attr_fk_notnull', 'attr_datetime', 'attr_date']
+    ['attr_text', 'attr_int', 'attr_bool', 'attr_fk', 'attr_fk_notnull',
+     'attr_datetime', 'attr_date', 'attr_datetimenull', 'attr_datenull']
 )
 
 
@@ -94,7 +97,8 @@ class VersioningForAdminTest(TestCase):
         obj_1.save()
         self.assertEqual(Revision.objects.get_for_object(obj_1).count(), 1)
 
-        obj_1.save()
+        obj_1.attr_text = obj_1.attr_text
+        obj_1.save()  # Not changed
         self.assertEqual(Revision.objects.get_for_object(obj_1).count(), 1)
 
         obj_2 = TestModel.objects.get(pk=obj_1.pk)
@@ -102,8 +106,10 @@ class VersioningForAdminTest(TestCase):
         obj_2.attr_bool = True
         obj_2.attr_fk = obj_fk_1
         obj_2.attr_fk_notnull = obj_fk_1
-        obj_2.attr_datetime = now()
-        obj_2.attr_date = date.today()
+        obj_2.attr_datetime += timedelta(days=2)
+        obj_2.attr_date += timedelta(days=2)
+        obj_2.attr_datetimenull = now()
+        obj_2.attr_datenull = date.today()
         obj_2.revision_info = {
             'editor': self.admin,
             'comment': 'comment 1',
@@ -117,8 +123,10 @@ class VersioningForAdminTest(TestCase):
         obj_3.attr_int = 3
         obj_3.attr_fk = obj_fk_2
         obj_3.attr_fk_notnull = obj_fk_2
-        obj_3.attr_datetime = None
-        obj_3.attr_date = None
+        obj_3.attr_datetime += timedelta(days=2)
+        obj_3.attr_date += timedelta(days=2)
+        obj_3.attr_datetimenull = None
+        obj_3.attr_datenull = None
         obj_3.revision_info = {
             'editor': self.admin,
             'comment': 'comment 1',
